# coding: utf-8

# flake8: noqa
"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from akeyless.models.api_key_access_rules import APIKeyAccessRules
from akeyless.models.awsiam_access_rules import AWSIAMAccessRules
from akeyless.models.aws_payload import AWSPayload
from akeyless.models.aws_secrets_migration import AWSSecretsMigration
from akeyless.models.account_general_settings import AccountGeneralSettings
from akeyless.models.account_object_version_settings_output import AccountObjectVersionSettingsOutput
from akeyless.models.active_directory_migration import ActiveDirectoryMigration
from akeyless.models.active_directory_payload import ActiveDirectoryPayload
from akeyless.models.admins_config_part import AdminsConfigPart
from akeyless.models.akeyless_gateway_config import AkeylessGatewayConfig
from akeyless.models.allowed_access import AllowedAccess
from akeyless.models.assoc_role_auth_method import AssocRoleAuthMethod
from akeyless.models.assoc_target_item import AssocTargetItem
from akeyless.models.attribute_type_and_value import AttributeTypeAndValue
from akeyless.models.auth import Auth
from akeyless.models.auth_method import AuthMethod
from akeyless.models.auth_method_access_info import AuthMethodAccessInfo
from akeyless.models.auth_method_role_association import AuthMethodRoleAssociation
from akeyless.models.auth_output import AuthOutput
from akeyless.models.aws_s3_log_forwarding_config import AwsS3LogForwardingConfig
from akeyless.models.azure_ad_access_rules import AzureADAccessRules
from akeyless.models.azure_key_vault_migration import AzureKeyVaultMigration
from akeyless.models.azure_log_analytics_forwarding_config import AzureLogAnalyticsForwardingConfig
from akeyless.models.azure_payload import AzurePayload
from akeyless.models.bastion_list_entry import BastionListEntry
from akeyless.models.bastions_list import BastionsList
from akeyless.models.cf_config_part import CFConfigPart
from akeyless.models.cache_config_part import CacheConfigPart
from akeyless.models.cert_access_rules import CertAccessRules
from akeyless.models.certificate_chain_info import CertificateChainInfo
from akeyless.models.certificate_expiration_event import CertificateExpirationEvent
from akeyless.models.certificate_info import CertificateInfo
from akeyless.models.certificate_issue_info import CertificateIssueInfo
from akeyless.models.classic_key_details_info import ClassicKeyDetailsInfo
from akeyless.models.classic_key_status_info import ClassicKeyStatusInfo
from akeyless.models.classic_key_target_info import ClassicKeyTargetInfo
from akeyless.models.client_data import ClientData
from akeyless.models.config_change import ConfigChange
from akeyless.models.config_hash import ConfigHash
from akeyless.models.configure import Configure
from akeyless.models.configure_output import ConfigureOutput
from akeyless.models.connect import Connect
from akeyless.models.create_aws_target import CreateAWSTarget
from akeyless.models.create_aws_target_output import CreateAWSTargetOutput
from akeyless.models.create_artifactory_target import CreateArtifactoryTarget
from akeyless.models.create_artifactory_target_output import CreateArtifactoryTargetOutput
from akeyless.models.create_auth_method import CreateAuthMethod
from akeyless.models.create_auth_method_awsiam import CreateAuthMethodAWSIAM
from akeyless.models.create_auth_method_awsiam_output import CreateAuthMethodAWSIAMOutput
from akeyless.models.create_auth_method_azure_ad import CreateAuthMethodAzureAD
from akeyless.models.create_auth_method_azure_ad_output import CreateAuthMethodAzureADOutput
from akeyless.models.create_auth_method_cert import CreateAuthMethodCert
from akeyless.models.create_auth_method_cert_output import CreateAuthMethodCertOutput
from akeyless.models.create_auth_method_gcp import CreateAuthMethodGCP
from akeyless.models.create_auth_method_gcp_output import CreateAuthMethodGCPOutput
from akeyless.models.create_auth_method_huawei import CreateAuthMethodHuawei
from akeyless.models.create_auth_method_huawei_output import CreateAuthMethodHuaweiOutput
from akeyless.models.create_auth_method_k8_s import CreateAuthMethodK8S
from akeyless.models.create_auth_method_k8_s_output import CreateAuthMethodK8SOutput
from akeyless.models.create_auth_method_ldap import CreateAuthMethodLDAP
from akeyless.models.create_auth_method_ldap_output import CreateAuthMethodLDAPOutput
from akeyless.models.create_auth_method_o_auth2 import CreateAuthMethodOAuth2
from akeyless.models.create_auth_method_o_auth2_output import CreateAuthMethodOAuth2Output
from akeyless.models.create_auth_method_oidc import CreateAuthMethodOIDC
from akeyless.models.create_auth_method_oidc_output import CreateAuthMethodOIDCOutput
from akeyless.models.create_auth_method_output import CreateAuthMethodOutput
from akeyless.models.create_auth_method_saml import CreateAuthMethodSAML
from akeyless.models.create_auth_method_saml_output import CreateAuthMethodSAMLOutput
from akeyless.models.create_auth_method_universal_identity import CreateAuthMethodUniversalIdentity
from akeyless.models.create_auth_method_universal_identity_output import CreateAuthMethodUniversalIdentityOutput
from akeyless.models.create_azure_target import CreateAzureTarget
from akeyless.models.create_azure_target_output import CreateAzureTargetOutput
from akeyless.models.create_classic_key import CreateClassicKey
from akeyless.models.create_classic_key_output import CreateClassicKeyOutput
from akeyless.models.create_db_target import CreateDBTarget
from akeyless.models.create_db_target_output import CreateDBTargetOutput
from akeyless.models.create_dfc_key import CreateDFCKey
from akeyless.models.create_dfc_key_output import CreateDFCKeyOutput
from akeyless.models.create_dockerhub_target import CreateDockerhubTarget
from akeyless.models.create_dockerhub_target_output import CreateDockerhubTargetOutput
from akeyless.models.create_dynamic_secret import CreateDynamicSecret
from akeyless.models.create_eks_target import CreateEKSTarget
from akeyless.models.create_eks_target_output import CreateEKSTargetOutput
from akeyless.models.create_event_forwarder import CreateEventForwarder
from akeyless.models.create_event_forwarder_output import CreateEventForwarderOutput
from akeyless.models.create_gke_target import CreateGKETarget
from akeyless.models.create_gke_target_output import CreateGKETargetOutput
from akeyless.models.create_gcp_target import CreateGcpTarget
from akeyless.models.create_gcp_target_output import CreateGcpTargetOutput
from akeyless.models.create_github_target import CreateGithubTarget
from akeyless.models.create_github_target_output import CreateGithubTargetOutput
from akeyless.models.create_key import CreateKey
from akeyless.models.create_key_output import CreateKeyOutput
from akeyless.models.create_ldap_target import CreateLdapTarget
from akeyless.models.create_ldap_target_output import CreateLdapTargetOutput
from akeyless.models.create_native_k8_s_target import CreateNativeK8STarget
from akeyless.models.create_native_k8_s_target_output import CreateNativeK8STargetOutput
from akeyless.models.create_pki_cert_issuer import CreatePKICertIssuer
from akeyless.models.create_pki_cert_issuer_output import CreatePKICertIssuerOutput
from akeyless.models.create_rabbit_mq_target import CreateRabbitMQTarget
from akeyless.models.create_rabbit_mq_target_output import CreateRabbitMQTargetOutput
from akeyless.models.create_role import CreateRole
from akeyless.models.create_role_auth_method_assoc_output import CreateRoleAuthMethodAssocOutput
from akeyless.models.create_rotated_secret import CreateRotatedSecret
from akeyless.models.create_rotated_secret_output import CreateRotatedSecretOutput
from akeyless.models.create_ssh_cert_issuer import CreateSSHCertIssuer
from akeyless.models.create_ssh_cert_issuer_output import CreateSSHCertIssuerOutput
from akeyless.models.create_ssh_target import CreateSSHTarget
from akeyless.models.create_ssh_target_output import CreateSSHTargetOutput
from akeyless.models.create_salesforce_target import CreateSalesforceTarget
from akeyless.models.create_salesforce_target_output import CreateSalesforceTargetOutput
from akeyless.models.create_secret import CreateSecret
from akeyless.models.create_secret_output import CreateSecretOutput
from akeyless.models.create_target_item_assoc_output import CreateTargetItemAssocOutput
from akeyless.models.create_tokenizer import CreateTokenizer
from akeyless.models.create_tokenizer_output import CreateTokenizerOutput
from akeyless.models.create_web_target import CreateWebTarget
from akeyless.models.create_web_target_output import CreateWebTargetOutput
from akeyless.models.customer_fragment import CustomerFragment
from akeyless.models.customer_fragments_json import CustomerFragmentsJson
from akeyless.models.customer_full_address import CustomerFullAddress
from akeyless.models.ds_producer_details import DSProducerDetails
from akeyless.models.data_protection_section import DataProtectionSection
from akeyless.models.datadog_forwarding_config import DatadogForwardingConfig
from akeyless.models.decrypt import Decrypt
from akeyless.models.decrypt_file import DecryptFile
from akeyless.models.decrypt_file_output import DecryptFileOutput
from akeyless.models.decrypt_output import DecryptOutput
from akeyless.models.decrypt_pkcs1 import DecryptPKCS1
from akeyless.models.decrypt_pkcs1_output import DecryptPKCS1Output
from akeyless.models.decrypt_with_classic_key import DecryptWithClassicKey
from akeyless.models.decrypt_with_classic_key_output import DecryptWithClassicKeyOutput
from akeyless.models.default_config_part import DefaultConfigPart
from akeyless.models.delete_auth_method import DeleteAuthMethod
from akeyless.models.delete_auth_method_output import DeleteAuthMethodOutput
from akeyless.models.delete_auth_methods import DeleteAuthMethods
from akeyless.models.delete_auth_methods_output import DeleteAuthMethodsOutput
from akeyless.models.delete_event_forwarder import DeleteEventForwarder
from akeyless.models.delete_item import DeleteItem
from akeyless.models.delete_item_output import DeleteItemOutput
from akeyless.models.delete_items import DeleteItems
from akeyless.models.delete_items_output import DeleteItemsOutput
from akeyless.models.delete_role import DeleteRole
from akeyless.models.delete_role_association import DeleteRoleAssociation
from akeyless.models.delete_role_rule import DeleteRoleRule
from akeyless.models.delete_role_rule_output import DeleteRoleRuleOutput
from akeyless.models.delete_roles import DeleteRoles
from akeyless.models.delete_target import DeleteTarget
from akeyless.models.delete_target_association import DeleteTargetAssociation
from akeyless.models.delete_targets import DeleteTargets
from akeyless.models.describe_item import DescribeItem
from akeyless.models.describe_permissions import DescribePermissions
from akeyless.models.describe_permissions_output import DescribePermissionsOutput
from akeyless.models.describe_sub_claims import DescribeSubClaims
from akeyless.models.describe_sub_claims_output import DescribeSubClaimsOutput
from akeyless.models.detokenize import Detokenize
from akeyless.models.detokenize_output import DetokenizeOutput
from akeyless.models.dynamic_secret_producer_info import DynamicSecretProducerInfo
from akeyless.models.elasticsearch_log_forwarding_config import ElasticsearchLogForwardingConfig
from akeyless.models.email_entry import EmailEntry
from akeyless.models.email_pass_access_rules import EmailPassAccessRules
from akeyless.models.email_tokenizer_info import EmailTokenizerInfo
from akeyless.models.encrypt import Encrypt
from akeyless.models.encrypt_file import EncryptFile
from akeyless.models.encrypt_file_output import EncryptFileOutput
from akeyless.models.encrypt_output import EncryptOutput
from akeyless.models.encrypt_with_classic_key import EncryptWithClassicKey
from akeyless.models.encrypt_with_classic_key_output import EncryptWithClassicKeyOutput
from akeyless.models.export_classic_key import ExportClassicKey
from akeyless.models.export_classic_key_output import ExportClassicKeyOutput
from akeyless.models.extension import Extension
from akeyless.models.external_kms_key_id import ExternalKMSKeyId
from akeyless.models.gcp_access_rules import GCPAccessRules
from akeyless.models.gcp_payload import GCPPayload
from akeyless.models.gcp_secrets_migration import GCPSecretsMigration
from akeyless.models.gateway_create_k8_s_auth_config import GatewayCreateK8SAuthConfig
from akeyless.models.gateway_create_k8_s_auth_config_output import GatewayCreateK8SAuthConfigOutput
from akeyless.models.gateway_create_migration import GatewayCreateMigration
from akeyless.models.gateway_create_producer_artifactory import GatewayCreateProducerArtifactory
from akeyless.models.gateway_create_producer_artifactory_output import GatewayCreateProducerArtifactoryOutput
from akeyless.models.gateway_create_producer_aws import GatewayCreateProducerAws
from akeyless.models.gateway_create_producer_aws_output import GatewayCreateProducerAwsOutput
from akeyless.models.gateway_create_producer_azure import GatewayCreateProducerAzure
from akeyless.models.gateway_create_producer_azure_output import GatewayCreateProducerAzureOutput
from akeyless.models.gateway_create_producer_cassandra import GatewayCreateProducerCassandra
from akeyless.models.gateway_create_producer_cassandra_output import GatewayCreateProducerCassandraOutput
from akeyless.models.gateway_create_producer_certificate_automation import GatewayCreateProducerCertificateAutomation
from akeyless.models.gateway_create_producer_certificate_automation_output import GatewayCreateProducerCertificateAutomationOutput
from akeyless.models.gateway_create_producer_chef import GatewayCreateProducerChef
from akeyless.models.gateway_create_producer_chef_output import GatewayCreateProducerChefOutput
from akeyless.models.gateway_create_producer_custom import GatewayCreateProducerCustom
from akeyless.models.gateway_create_producer_custom_output import GatewayCreateProducerCustomOutput
from akeyless.models.gateway_create_producer_dockerhub import GatewayCreateProducerDockerhub
from akeyless.models.gateway_create_producer_dockerhub_output import GatewayCreateProducerDockerhubOutput
from akeyless.models.gateway_create_producer_eks import GatewayCreateProducerEks
from akeyless.models.gateway_create_producer_eks_output import GatewayCreateProducerEksOutput
from akeyless.models.gateway_create_producer_gcp import GatewayCreateProducerGcp
from akeyless.models.gateway_create_producer_gcp_output import GatewayCreateProducerGcpOutput
from akeyless.models.gateway_create_producer_github import GatewayCreateProducerGithub
from akeyless.models.gateway_create_producer_github_output import GatewayCreateProducerGithubOutput
from akeyless.models.gateway_create_producer_gke import GatewayCreateProducerGke
from akeyless.models.gateway_create_producer_gke_output import GatewayCreateProducerGkeOutput
from akeyless.models.gateway_create_producer_hana_db import GatewayCreateProducerHanaDb
from akeyless.models.gateway_create_producer_hana_db_output import GatewayCreateProducerHanaDbOutput
from akeyless.models.gateway_create_producer_ldap import GatewayCreateProducerLdap
from akeyless.models.gateway_create_producer_ldap_output import GatewayCreateProducerLdapOutput
from akeyless.models.gateway_create_producer_mssql import GatewayCreateProducerMSSQL
from akeyless.models.gateway_create_producer_mssql_output import GatewayCreateProducerMSSQLOutput
from akeyless.models.gateway_create_producer_mongo import GatewayCreateProducerMongo
from akeyless.models.gateway_create_producer_mongo_output import GatewayCreateProducerMongoOutput
from akeyless.models.gateway_create_producer_my_sql import GatewayCreateProducerMySQL
from akeyless.models.gateway_create_producer_my_sql_output import GatewayCreateProducerMySQLOutput
from akeyless.models.gateway_create_producer_native_k8_s import GatewayCreateProducerNativeK8S
from akeyless.models.gateway_create_producer_native_k8_s_output import GatewayCreateProducerNativeK8SOutput
from akeyless.models.gateway_create_producer_oracle_db import GatewayCreateProducerOracleDb
from akeyless.models.gateway_create_producer_oracle_db_output import GatewayCreateProducerOracleDbOutput
from akeyless.models.gateway_create_producer_postgre_sql import GatewayCreateProducerPostgreSQL
from akeyless.models.gateway_create_producer_postgre_sql_output import GatewayCreateProducerPostgreSQLOutput
from akeyless.models.gateway_create_producer_rabbit_mq import GatewayCreateProducerRabbitMQ
from akeyless.models.gateway_create_producer_rabbit_mq_output import GatewayCreateProducerRabbitMQOutput
from akeyless.models.gateway_create_producer_rdp import GatewayCreateProducerRdp
from akeyless.models.gateway_create_producer_rdp_output import GatewayCreateProducerRdpOutput
from akeyless.models.gateway_create_producer_redshift import GatewayCreateProducerRedshift
from akeyless.models.gateway_create_producer_redshift_output import GatewayCreateProducerRedshiftOutput
from akeyless.models.gateway_create_producer_snowflake import GatewayCreateProducerSnowflake
from akeyless.models.gateway_create_producer_snowflake_output import GatewayCreateProducerSnowflakeOutput
from akeyless.models.gateway_delete_allowed_management_access import GatewayDeleteAllowedManagementAccess
from akeyless.models.gateway_delete_k8_s_auth_config import GatewayDeleteK8SAuthConfig
from akeyless.models.gateway_delete_k8_s_auth_config_output import GatewayDeleteK8SAuthConfigOutput
from akeyless.models.gateway_delete_migration import GatewayDeleteMigration
from akeyless.models.gateway_delete_producer import GatewayDeleteProducer
from akeyless.models.gateway_delete_producer_output import GatewayDeleteProducerOutput
from akeyless.models.gateway_get_config import GatewayGetConfig
from akeyless.models.gateway_get_k8_s_auth_config import GatewayGetK8SAuthConfig
from akeyless.models.gateway_get_k8_s_auth_config_output import GatewayGetK8SAuthConfigOutput
from akeyless.models.gateway_get_ldap_auth_config import GatewayGetLdapAuthConfig
from akeyless.models.gateway_get_ldap_auth_config_output import GatewayGetLdapAuthConfigOutput
from akeyless.models.gateway_get_migration import GatewayGetMigration
from akeyless.models.gateway_get_producer import GatewayGetProducer
from akeyless.models.gateway_get_tmp_users import GatewayGetTmpUsers
from akeyless.models.gateway_list_allowed_management_access import GatewayListAllowedManagementAccess
from akeyless.models.gateway_list_migration import GatewayListMigration
from akeyless.models.gateway_list_producers import GatewayListProducers
from akeyless.models.gateway_message_queue_info import GatewayMessageQueueInfo
from akeyless.models.gateway_migrate_personal_items import GatewayMigratePersonalItems
from akeyless.models.gateway_migrate_personal_items_output import GatewayMigratePersonalItemsOutput
from akeyless.models.gateway_migration_create_output import GatewayMigrationCreateOutput
from akeyless.models.gateway_migration_delete_output import GatewayMigrationDeleteOutput
from akeyless.models.gateway_migration_get_output import GatewayMigrationGetOutput
from akeyless.models.gateway_migration_list_output import GatewayMigrationListOutput
from akeyless.models.gateway_migration_sync_output import GatewayMigrationSyncOutput
from akeyless.models.gateway_migration_update_output import GatewayMigrationUpdateOutput
from akeyless.models.gateway_revoke_tmp_users import GatewayRevokeTmpUsers
from akeyless.models.gateway_start_producer import GatewayStartProducer
from akeyless.models.gateway_start_producer_output import GatewayStartProducerOutput
from akeyless.models.gateway_status_migration import GatewayStatusMigration
from akeyless.models.gateway_stop_producer import GatewayStopProducer
from akeyless.models.gateway_stop_producer_output import GatewayStopProducerOutput
from akeyless.models.gateway_sync_migration import GatewaySyncMigration
from akeyless.models.gateway_update_item import GatewayUpdateItem
from akeyless.models.gateway_update_item_output import GatewayUpdateItemOutput
from akeyless.models.gateway_update_k8_s_auth_config import GatewayUpdateK8SAuthConfig
from akeyless.models.gateway_update_k8_s_auth_config_output import GatewayUpdateK8SAuthConfigOutput
from akeyless.models.gateway_update_ldap_auth_config import GatewayUpdateLdapAuthConfig
from akeyless.models.gateway_update_ldap_auth_config_output import GatewayUpdateLdapAuthConfigOutput
from akeyless.models.gateway_update_migration import GatewayUpdateMigration
from akeyless.models.gateway_update_producer_artifactory import GatewayUpdateProducerArtifactory
from akeyless.models.gateway_update_producer_artifactory_output import GatewayUpdateProducerArtifactoryOutput
from akeyless.models.gateway_update_producer_aws import GatewayUpdateProducerAws
from akeyless.models.gateway_update_producer_aws_output import GatewayUpdateProducerAwsOutput
from akeyless.models.gateway_update_producer_azure import GatewayUpdateProducerAzure
from akeyless.models.gateway_update_producer_azure_output import GatewayUpdateProducerAzureOutput
from akeyless.models.gateway_update_producer_cassandra import GatewayUpdateProducerCassandra
from akeyless.models.gateway_update_producer_cassandra_output import GatewayUpdateProducerCassandraOutput
from akeyless.models.gateway_update_producer_certificate_automation import GatewayUpdateProducerCertificateAutomation
from akeyless.models.gateway_update_producer_certificate_automation_output import GatewayUpdateProducerCertificateAutomationOutput
from akeyless.models.gateway_update_producer_chef import GatewayUpdateProducerChef
from akeyless.models.gateway_update_producer_chef_output import GatewayUpdateProducerChefOutput
from akeyless.models.gateway_update_producer_custom import GatewayUpdateProducerCustom
from akeyless.models.gateway_update_producer_custom_output import GatewayUpdateProducerCustomOutput
from akeyless.models.gateway_update_producer_dockerhub import GatewayUpdateProducerDockerhub
from akeyless.models.gateway_update_producer_dockerhub_output import GatewayUpdateProducerDockerhubOutput
from akeyless.models.gateway_update_producer_eks import GatewayUpdateProducerEks
from akeyless.models.gateway_update_producer_eks_output import GatewayUpdateProducerEksOutput
from akeyless.models.gateway_update_producer_gcp import GatewayUpdateProducerGcp
from akeyless.models.gateway_update_producer_gcp_output import GatewayUpdateProducerGcpOutput
from akeyless.models.gateway_update_producer_github import GatewayUpdateProducerGithub
from akeyless.models.gateway_update_producer_github_output import GatewayUpdateProducerGithubOutput
from akeyless.models.gateway_update_producer_gke import GatewayUpdateProducerGke
from akeyless.models.gateway_update_producer_gke_output import GatewayUpdateProducerGkeOutput
from akeyless.models.gateway_update_producer_hana_db import GatewayUpdateProducerHanaDb
from akeyless.models.gateway_update_producer_hana_db_output import GatewayUpdateProducerHanaDbOutput
from akeyless.models.gateway_update_producer_ldap import GatewayUpdateProducerLdap
from akeyless.models.gateway_update_producer_ldap_output import GatewayUpdateProducerLdapOutput
from akeyless.models.gateway_update_producer_mssql import GatewayUpdateProducerMSSQL
from akeyless.models.gateway_update_producer_mssql_output import GatewayUpdateProducerMSSQLOutput
from akeyless.models.gateway_update_producer_mongo import GatewayUpdateProducerMongo
from akeyless.models.gateway_update_producer_mongo_output import GatewayUpdateProducerMongoOutput
from akeyless.models.gateway_update_producer_my_sql import GatewayUpdateProducerMySQL
from akeyless.models.gateway_update_producer_my_sql_output import GatewayUpdateProducerMySQLOutput
from akeyless.models.gateway_update_producer_native_k8_s import GatewayUpdateProducerNativeK8S
from akeyless.models.gateway_update_producer_native_k8_s_output import GatewayUpdateProducerNativeK8SOutput
from akeyless.models.gateway_update_producer_oracle_db import GatewayUpdateProducerOracleDb
from akeyless.models.gateway_update_producer_oracle_db_output import GatewayUpdateProducerOracleDbOutput
from akeyless.models.gateway_update_producer_postgre_sql import GatewayUpdateProducerPostgreSQL
from akeyless.models.gateway_update_producer_postgre_sql_output import GatewayUpdateProducerPostgreSQLOutput
from akeyless.models.gateway_update_producer_rabbit_mq import GatewayUpdateProducerRabbitMQ
from akeyless.models.gateway_update_producer_rabbit_mq_output import GatewayUpdateProducerRabbitMQOutput
from akeyless.models.gateway_update_producer_rdp import GatewayUpdateProducerRdp
from akeyless.models.gateway_update_producer_rdp_output import GatewayUpdateProducerRdpOutput
from akeyless.models.gateway_update_producer_redshift import GatewayUpdateProducerRedshift
from akeyless.models.gateway_update_producer_redshift_output import GatewayUpdateProducerRedshiftOutput
from akeyless.models.gateway_update_producer_snowflake import GatewayUpdateProducerSnowflake
from akeyless.models.gateway_update_producer_snowflake_output import GatewayUpdateProducerSnowflakeOutput
from akeyless.models.gateway_update_tmp_users import GatewayUpdateTmpUsers
from akeyless.models.gateways_list_response import GatewaysListResponse
from akeyless.models.gen_customer_fragment import GenCustomerFragment
from akeyless.models.general_config_part import GeneralConfigPart
from akeyless.models.get_account_settings import GetAccountSettings
from akeyless.models.get_account_settings_command_output import GetAccountSettingsCommandOutput
from akeyless.models.get_auth_method import GetAuthMethod
from akeyless.models.get_dynamic_secret_value import GetDynamicSecretValue
from akeyless.models.get_event_forwarder import GetEventForwarder
from akeyless.models.get_event_forwarder_output import GetEventForwarderOutput
from akeyless.models.get_kube_exec_creds import GetKubeExecCreds
from akeyless.models.get_kube_exec_creds_output import GetKubeExecCredsOutput
from akeyless.models.get_pki_certificate import GetPKICertificate
from akeyless.models.get_pki_certificate_output import GetPKICertificateOutput
from akeyless.models.get_producers_list_reply_obj import GetProducersListReplyObj
from akeyless.models.get_rsa_public import GetRSAPublic
from akeyless.models.get_rsa_public_output import GetRSAPublicOutput
from akeyless.models.get_role import GetRole
from akeyless.models.get_rotated_secret_value import GetRotatedSecretValue
from akeyless.models.get_ssh_certificate import GetSSHCertificate
from akeyless.models.get_ssh_certificate_output import GetSSHCertificateOutput
from akeyless.models.get_secret_value import GetSecretValue
from akeyless.models.get_sub_admins_list_reply_obj import GetSubAdminsListReplyObj
from akeyless.models.get_tags import GetTags
from akeyless.models.get_target import GetTarget
from akeyless.models.get_target_details import GetTargetDetails
from akeyless.models.get_target_details_output import GetTargetDetailsOutput
from akeyless.models.gw_cluster_identity import GwClusterIdentity
from akeyless.models.hashi_migration import HashiMigration
from akeyless.models.hashi_payload import HashiPayload
from akeyless.models.huawei_access_rules import HuaweiAccessRules
from akeyless.models.item import Item
from akeyless.models.item_general_info import ItemGeneralInfo
from akeyless.models.item_target_association import ItemTargetAssociation
from akeyless.models.item_version import ItemVersion
from akeyless.models.json_error import JSONError
from akeyless.models.k8_s_auth import K8SAuth
from akeyless.models.k8_s_auths_config_last_change import K8SAuthsConfigLastChange
from akeyless.models.k8_s_auths_config_part import K8SAuthsConfigPart
from akeyless.models.k8_s_migration import K8SMigration
from akeyless.models.k8_s_payload import K8SPayload
from akeyless.models.kmip_client import KMIPClient
from akeyless.models.kmip_client_get_response import KMIPClientGetResponse
from akeyless.models.kmip_client_list_response import KMIPClientListResponse
from akeyless.models.kmip_client_update_response import KMIPClientUpdateResponse
from akeyless.models.kmip_config_part import KMIPConfigPart
from akeyless.models.kmip_environment_create_response import KMIPEnvironmentCreateResponse
from akeyless.models.kmip_server import KMIPServer
from akeyless.models.kmip_client_delete_rule import KmipClientDeleteRule
from akeyless.models.kmip_client_set_rule import KmipClientSetRule
from akeyless.models.kmip_create_client import KmipCreateClient
from akeyless.models.kmip_create_client_output import KmipCreateClientOutput
from akeyless.models.kmip_delete_client import KmipDeleteClient
from akeyless.models.kmip_delete_server import KmipDeleteServer
from akeyless.models.kmip_describe_client import KmipDescribeClient
from akeyless.models.kmip_describe_server import KmipDescribeServer
from akeyless.models.kmip_describe_server_output import KmipDescribeServerOutput
from akeyless.models.kmip_list_clients import KmipListClients
from akeyless.models.kmip_move_server import KmipMoveServer
from akeyless.models.kmip_move_server_output import KmipMoveServerOutput
from akeyless.models.kmip_renew_client_certificate import KmipRenewClientCertificate
from akeyless.models.kmip_renew_client_certificate_output import KmipRenewClientCertificateOutput
from akeyless.models.kmip_renew_server_certificate import KmipRenewServerCertificate
from akeyless.models.kmip_renew_server_certificate_output import KmipRenewServerCertificateOutput
from akeyless.models.kmip_server_setup import KmipServerSetup
from akeyless.models.kmip_set_server_state import KmipSetServerState
from akeyless.models.kmip_set_server_state_output import KmipSetServerStateOutput
from akeyless.models.kubernetes_access_rules import KubernetesAccessRules
from akeyless.models.ldap_access_rules import LDAPAccessRules
from akeyless.models.last_config_change import LastConfigChange
from akeyless.models.last_status_info import LastStatusInfo
from akeyless.models.ldap_config_part import LdapConfigPart
from akeyless.models.leadership_config_part import LeadershipConfigPart
from akeyless.models.list_auth_methods import ListAuthMethods
from akeyless.models.list_auth_methods_output import ListAuthMethodsOutput
from akeyless.models.list_gateways import ListGateways
from akeyless.models.list_items import ListItems
from akeyless.models.list_items_in_path_output import ListItemsInPathOutput
from akeyless.models.list_roles import ListRoles
from akeyless.models.list_roles_output import ListRolesOutput
from akeyless.models.list_sra_bastions import ListSRABastions
from akeyless.models.list_shared_items import ListSharedItems
from akeyless.models.list_targets import ListTargets
from akeyless.models.list_targets_output import ListTargetsOutput
from akeyless.models.log_forwarding_config_part import LogForwardingConfigPart
from akeyless.models.logstash_log_forwarding_config import LogstashLogForwardingConfig
from akeyless.models.logz_io_log_forwarding_config import LogzIoLogForwardingConfig
from akeyless.models.migration_general import MigrationGeneral
from akeyless.models.migration_items import MigrationItems
from akeyless.models.migration_status import MigrationStatus
from akeyless.models.migration_status_reply_obj import MigrationStatusReplyObj
from akeyless.models.migrations_config_last_change import MigrationsConfigLastChange
from akeyless.models.migrations_config_part import MigrationsConfigPart
from akeyless.models.mock_migration import MockMigration
from akeyless.models.mock_payload import MockPayload
from akeyless.models.move_objects import MoveObjects
from akeyless.models.name import Name
from akeyless.models.noti_forwarder import NotiForwarder
from akeyless.models.o_auth2_access_rules import OAuth2AccessRules
from akeyless.models.o_auth2_custom_claim import OAuth2CustomClaim
from akeyless.models.oidc_access_rules import OIDCAccessRules
from akeyless.models.oidc_custom_claim import OIDCCustomClaim
from akeyless.models.object_version_settings_output import ObjectVersionSettingsOutput
from akeyless.models.one_password_migration import OnePasswordMigration
from akeyless.models.one_password_payload import OnePasswordPayload
from akeyless.models.pki_certificate_issue_details import PKICertificateIssueDetails
from akeyless.models.password_policy_info import PasswordPolicyInfo
from akeyless.models.path_rule import PathRule
from akeyless.models.producer import Producer
from akeyless.models.producers_config_part import ProducersConfigPart
from akeyless.models.raw_creds import RawCreds
from akeyless.models.refresh_key import RefreshKey
from akeyless.models.refresh_key_output import RefreshKeyOutput
from akeyless.models.regexp_tokenizer_info import RegexpTokenizerInfo
from akeyless.models.request_access import RequestAccess
from akeyless.models.request_access_output import RequestAccessOutput
from akeyless.models.required_activity import RequiredActivity
from akeyless.models.reverse_rbac import ReverseRBAC
from akeyless.models.reverse_rbac_client import ReverseRBACClient
from akeyless.models.reverse_rbac_output import ReverseRBACOutput
from akeyless.models.revoke_creds import RevokeCreds
from akeyless.models.role import Role
from akeyless.models.role_auth_method_association import RoleAuthMethodAssociation
from akeyless.models.rollback_secret import RollbackSecret
from akeyless.models.rollback_secret_output import RollbackSecretOutput
from akeyless.models.rotate_key import RotateKey
from akeyless.models.rotate_key_output import RotateKeyOutput
from akeyless.models.rotate_secret import RotateSecret
from akeyless.models.rotated_secret_details_info import RotatedSecretDetailsInfo
from akeyless.models.rotated_secret_output import RotatedSecretOutput
from akeyless.models.rotator import Rotator
from akeyless.models.rotators_config_part import RotatorsConfigPart
from akeyless.models.rule_assigner import RuleAssigner
from akeyless.models.rules import Rules
from akeyless.models.saml_access_rules import SAMLAccessRules
from akeyless.models.saml_attribute import SAMLAttribute
from akeyless.models.ssh_certificate_issue_details import SSHCertificateIssueDetails
from akeyless.models.secure_remote_access import SecureRemoteAccess
from akeyless.models.set_item_state import SetItemState
from akeyless.models.set_role_rule import SetRoleRule
from akeyless.models.share_item import ShareItem
from akeyless.models.sign_jwt_output import SignJWTOutput
from akeyless.models.sign_jwt_with_classic_key import SignJWTWithClassicKey
from akeyless.models.sign_pkcs1 import SignPKCS1
from akeyless.models.sign_pkcs1_output import SignPKCS1Output
from akeyless.models.sign_pki_cert_output import SignPKICertOutput
from akeyless.models.sign_pki_cert_with_classic_key import SignPKICertWithClassicKey
from akeyless.models.sm_info import SmInfo
from akeyless.models.splunk_log_forwarding_config import SplunkLogForwardingConfig
from akeyless.models.sra_info import SraInfo
from akeyless.models.static_creds_auth import StaticCredsAuth
from akeyless.models.static_creds_auth_output import StaticCredsAuthOutput
from akeyless.models.static_secret_details_info import StaticSecretDetailsInfo
from akeyless.models.syslog_log_forwarding_config import SyslogLogForwardingConfig
from akeyless.models.system_access_credentials_reply_obj import SystemAccessCredentialsReplyObj
from akeyless.models.system_access_creds_settings import SystemAccessCredsSettings
from akeyless.models.target import Target
from akeyless.models.target_item_association import TargetItemAssociation
from akeyless.models.target_item_version import TargetItemVersion
from akeyless.models.target_type_details_input import TargetTypeDetailsInput
from akeyless.models.tmp_user_data import TmpUserData
from akeyless.models.tokenize import Tokenize
from akeyless.models.tokenize_output import TokenizeOutput
from akeyless.models.tokenizer_info import TokenizerInfo
from akeyless.models.uid_token_details import UIDTokenDetails
from akeyless.models.uid_create_child_token import UidCreateChildToken
from akeyless.models.uid_create_child_token_output import UidCreateChildTokenOutput
from akeyless.models.uid_generate_token import UidGenerateToken
from akeyless.models.uid_generate_token_output import UidGenerateTokenOutput
from akeyless.models.uid_list_children import UidListChildren
from akeyless.models.uid_revoke_token import UidRevokeToken
from akeyless.models.uid_rotate_token import UidRotateToken
from akeyless.models.uid_rotate_token_output import UidRotateTokenOutput
from akeyless.models.unconfigure import Unconfigure
from akeyless.models.universal_identity_access_rules import UniversalIdentityAccessRules
from akeyless.models.universal_identity_details import UniversalIdentityDetails
from akeyless.models.update import Update
from akeyless.models.update_aws_target import UpdateAWSTarget
from akeyless.models.update_aws_target_details import UpdateAWSTargetDetails
from akeyless.models.update_account_settings import UpdateAccountSettings
from akeyless.models.update_account_settings_output import UpdateAccountSettingsOutput
from akeyless.models.update_artifactory_target import UpdateArtifactoryTarget
from akeyless.models.update_artifactory_target_output import UpdateArtifactoryTargetOutput
from akeyless.models.update_assoc import UpdateAssoc
from akeyless.models.update_auth_method import UpdateAuthMethod
from akeyless.models.update_auth_method_awsiam import UpdateAuthMethodAWSIAM
from akeyless.models.update_auth_method_azure_ad import UpdateAuthMethodAzureAD
from akeyless.models.update_auth_method_cert import UpdateAuthMethodCert
from akeyless.models.update_auth_method_cert_output import UpdateAuthMethodCertOutput
from akeyless.models.update_auth_method_gcp import UpdateAuthMethodGCP
from akeyless.models.update_auth_method_k8_s import UpdateAuthMethodK8S
from akeyless.models.update_auth_method_k8_s_output import UpdateAuthMethodK8SOutput
from akeyless.models.update_auth_method_ldap import UpdateAuthMethodLDAP
from akeyless.models.update_auth_method_ldap_output import UpdateAuthMethodLDAPOutput
from akeyless.models.update_auth_method_o_auth2 import UpdateAuthMethodOAuth2
from akeyless.models.update_auth_method_oidc import UpdateAuthMethodOIDC
from akeyless.models.update_auth_method_output import UpdateAuthMethodOutput
from akeyless.models.update_auth_method_saml import UpdateAuthMethodSAML
from akeyless.models.update_auth_method_universal_identity import UpdateAuthMethodUniversalIdentity
from akeyless.models.update_azure_target import UpdateAzureTarget
from akeyless.models.update_azure_target_output import UpdateAzureTargetOutput
from akeyless.models.update_db_target import UpdateDBTarget
from akeyless.models.update_db_target_details import UpdateDBTargetDetails
from akeyless.models.update_db_target_output import UpdateDBTargetOutput
from akeyless.models.update_dockerhub_target import UpdateDockerhubTarget
from akeyless.models.update_dockerhub_target_output import UpdateDockerhubTargetOutput
from akeyless.models.update_eks_target import UpdateEKSTarget
from akeyless.models.update_eks_target_output import UpdateEKSTargetOutput
from akeyless.models.update_event_forwarder import UpdateEventForwarder
from akeyless.models.update_gke_target import UpdateGKETarget
from akeyless.models.update_gke_target_output import UpdateGKETargetOutput
from akeyless.models.update_gcp_target import UpdateGcpTarget
from akeyless.models.update_gcp_target_output import UpdateGcpTargetOutput
from akeyless.models.update_github_target import UpdateGithubTarget
from akeyless.models.update_github_target_output import UpdateGithubTargetOutput
from akeyless.models.update_item import UpdateItem
from akeyless.models.update_item_output import UpdateItemOutput
from akeyless.models.update_ldap_target import UpdateLdapTarget
from akeyless.models.update_ldap_target_details import UpdateLdapTargetDetails
from akeyless.models.update_ldap_target_output import UpdateLdapTargetOutput
from akeyless.models.update_native_k8_s_target import UpdateNativeK8STarget
from akeyless.models.update_native_k8_s_target_output import UpdateNativeK8STargetOutput
from akeyless.models.update_output import UpdateOutput
from akeyless.models.update_pki_cert_issuer import UpdatePKICertIssuer
from akeyless.models.update_pki_cert_issuer_output import UpdatePKICertIssuerOutput
from akeyless.models.update_rdp_target_details import UpdateRDPTargetDetails
from akeyless.models.update_rabbit_mq_target import UpdateRabbitMQTarget
from akeyless.models.update_rabbit_mq_target_details import UpdateRabbitMQTargetDetails
from akeyless.models.update_rabbit_mq_target_output import UpdateRabbitMQTargetOutput
from akeyless.models.update_role import UpdateRole
from akeyless.models.update_role_output import UpdateRoleOutput
from akeyless.models.update_rotated_secret import UpdateRotatedSecret
from akeyless.models.update_rotated_secret_output import UpdateRotatedSecretOutput
from akeyless.models.update_rotation_settings import UpdateRotationSettings
from akeyless.models.update_ssh_cert_issuer import UpdateSSHCertIssuer
from akeyless.models.update_ssh_cert_issuer_output import UpdateSSHCertIssuerOutput
from akeyless.models.update_ssh_target import UpdateSSHTarget
from akeyless.models.update_ssh_target_details import UpdateSSHTargetDetails
from akeyless.models.update_ssh_target_output import UpdateSSHTargetOutput
from akeyless.models.update_salesforce_target import UpdateSalesforceTarget
from akeyless.models.update_salesforce_target_output import UpdateSalesforceTargetOutput
from akeyless.models.update_secret_val import UpdateSecretVal
from akeyless.models.update_secret_val_output import UpdateSecretValOutput
from akeyless.models.update_target import UpdateTarget
from akeyless.models.update_target_details import UpdateTargetDetails
from akeyless.models.update_target_details_output import UpdateTargetDetailsOutput
from akeyless.models.update_target_output import UpdateTargetOutput
from akeyless.models.update_web_target import UpdateWebTarget
from akeyless.models.update_web_target_details import UpdateWebTargetDetails
from akeyless.models.update_web_target_output import UpdateWebTargetOutput
from akeyless.models.upload_pkcs12 import UploadPKCS12
from akeyless.models.upload_rsa import UploadRSA
from akeyless.models.validate_token import ValidateToken
from akeyless.models.validate_token_output import ValidateTokenOutput
from akeyless.models.vaultless_tokenizer_info import VaultlessTokenizerInfo
from akeyless.models.verify_jwt_output import VerifyJWTOutput
from akeyless.models.verify_jwt_with_classic_key import VerifyJWTWithClassicKey
from akeyless.models.verify_pkcs1 import VerifyPKCS1
from akeyless.models.verify_pki_cert_output import VerifyPKICertOutput
from akeyless.models.verify_pki_cert_with_classic_key import VerifyPKICertWithClassicKey



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class VerifyPKICertWithClassicKey(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'display_id': 'str',
        'json': 'bool',
        'pki_cert': 'str',
        'token': 'str',
        'uid_token': 'str',
        'version': 'int'
    }

    attribute_map = {
        'display_id': 'display-id',
        'json': 'json',
        'pki_cert': 'pki-cert',
        'token': 'token',
        'uid_token': 'uid-token',
        'version': 'version'
    }

    def __init__(self, display_id=None, json=None, pki_cert=None, token=None, uid_token=None, version=None, local_vars_configuration=None):  # noqa: E501
        """VerifyPKICertWithClassicKey - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._display_id = None
        self._json = None
        self._pki_cert = None
        self._token = None
        self._uid_token = None
        self._version = None
        self.discriminator = None

        self.display_id = display_id
        if json is not None:
            self.json = json
        self.pki_cert = pki_cert
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        self.version = version

    @property
    def display_id(self):
        """Gets the display_id of this VerifyPKICertWithClassicKey.  # noqa: E501

        The name of the key to use in the verify PKICert process  # noqa: E501

        :return: The display_id of this VerifyPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._display_id

    @display_id.setter
    def display_id(self, display_id):
        """Sets the display_id of this VerifyPKICertWithClassicKey.

        The name of the key to use in the verify PKICert process  # noqa: E501

        :param display_id: The display_id of this VerifyPKICertWithClassicKey.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and display_id is None:  # noqa: E501
            raise ValueError("Invalid value for `display_id`, must not be `None`")  # noqa: E501

        self._display_id = display_id

    @property
    def json(self):
        """Gets the json of this VerifyPKICertWithClassicKey.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this VerifyPKICertWithClassicKey.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this VerifyPKICertWithClassicKey.

        Set output format to JSON  # noqa: E501

        :param json: The json of this VerifyPKICertWithClassicKey.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def pki_cert(self):
        """Gets the pki_cert of this VerifyPKICertWithClassicKey.  # noqa: E501

        PkiCert  # noqa: E501

        :return: The pki_cert of this VerifyPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._pki_cert

    @pki_cert.setter
    def pki_cert(self, pki_cert):
        """Sets the pki_cert of this VerifyPKICertWithClassicKey.

        PkiCert  # noqa: E501

        :param pki_cert: The pki_cert of this VerifyPKICertWithClassicKey.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and pki_cert is None:  # noqa: E501
            raise ValueError("Invalid value for `pki_cert`, must not be `None`")  # noqa: E501

        self._pki_cert = pki_cert

    @property
    def token(self):
        """Gets the token of this VerifyPKICertWithClassicKey.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this VerifyPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this VerifyPKICertWithClassicKey.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this VerifyPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this VerifyPKICertWithClassicKey.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this VerifyPKICertWithClassicKey.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this VerifyPKICertWithClassicKey.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this VerifyPKICertWithClassicKey.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def version(self):
        """Gets the version of this VerifyPKICertWithClassicKey.  # noqa: E501

        classic key version  # noqa: E501

        :return: The version of this VerifyPKICertWithClassicKey.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this VerifyPKICertWithClassicKey.

        classic key version  # noqa: E501

        :param version: The version of this VerifyPKICertWithClassicKey.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VerifyPKICertWithClassicKey):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VerifyPKICertWithClassicKey):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UIdentityConfigPart(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uid_access_id': 'str',
        'uid_enable': 'bool',
        'uid_rotate_interval': 'str',
        'uid_status': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'uid_access_id': 'uid_access_id',
        'uid_enable': 'uid_enable',
        'uid_rotate_interval': 'uid_rotate_interval',
        'uid_status': 'uid_status',
        'uid_token': 'uid_token'
    }

    def __init__(self, uid_access_id=None, uid_enable=None, uid_rotate_interval=None, uid_status=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """UIdentityConfigPart - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uid_access_id = None
        self._uid_enable = None
        self._uid_rotate_interval = None
        self._uid_status = None
        self._uid_token = None
        self.discriminator = None

        if uid_access_id is not None:
            self.uid_access_id = uid_access_id
        if uid_enable is not None:
            self.uid_enable = uid_enable
        if uid_rotate_interval is not None:
            self.uid_rotate_interval = uid_rotate_interval
        if uid_status is not None:
            self.uid_status = uid_status
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def uid_access_id(self):
        """Gets the uid_access_id of this UIdentityConfigPart.  # noqa: E501


        :return: The uid_access_id of this UIdentityConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._uid_access_id

    @uid_access_id.setter
    def uid_access_id(self, uid_access_id):
        """Sets the uid_access_id of this UIdentityConfigPart.


        :param uid_access_id: The uid_access_id of this UIdentityConfigPart.  # noqa: E501
        :type: str
        """

        self._uid_access_id = uid_access_id

    @property
    def uid_enable(self):
        """Gets the uid_enable of this UIdentityConfigPart.  # noqa: E501


        :return: The uid_enable of this UIdentityConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._uid_enable

    @uid_enable.setter
    def uid_enable(self, uid_enable):
        """Sets the uid_enable of this UIdentityConfigPart.


        :param uid_enable: The uid_enable of this UIdentityConfigPart.  # noqa: E501
        :type: bool
        """

        self._uid_enable = uid_enable

    @property
    def uid_rotate_interval(self):
        """Gets the uid_rotate_interval of this UIdentityConfigPart.  # noqa: E501


        :return: The uid_rotate_interval of this UIdentityConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._uid_rotate_interval

    @uid_rotate_interval.setter
    def uid_rotate_interval(self, uid_rotate_interval):
        """Sets the uid_rotate_interval of this UIdentityConfigPart.


        :param uid_rotate_interval: The uid_rotate_interval of this UIdentityConfigPart.  # noqa: E501
        :type: str
        """

        self._uid_rotate_interval = uid_rotate_interval

    @property
    def uid_status(self):
        """Gets the uid_status of this UIdentityConfigPart.  # noqa: E501


        :return: The uid_status of this UIdentityConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._uid_status

    @uid_status.setter
    def uid_status(self, uid_status):
        """Sets the uid_status of this UIdentityConfigPart.


        :param uid_status: The uid_status of this UIdentityConfigPart.  # noqa: E501
        :type: str
        """

        self._uid_status = uid_status

    @property
    def uid_token(self):
        """Gets the uid_token of this UIdentityConfigPart.  # noqa: E501


        :return: The uid_token of this UIdentityConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UIdentityConfigPart.


        :param uid_token: The uid_token of this UIdentityConfigPart.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UIdentityConfigPart):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UIdentityConfigPart):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.universal_identity_details import UniversalIdentityDetails  # noqa: E501
from akeyless.rest import ApiException

class TestUniversalIdentityDetails(unittest.TestCase):
    """UniversalIdentityDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UniversalIdentityDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.universal_identity_details.UniversalIdentityDetails()  # noqa: E501
        if include_optional :
            return UniversalIdentityDetails(
                max_depth = 56, 
                number_of_tokens = 56, 
                root = akeyless.models.uid_token_details_universal_identity_type/.UIDTokenDetails Universal identity type.(
                    children = {
                        'key' : akeyless.models.uid_token_details_universal_identity_type/.UIDTokenDetails Universal identity type.(
                            comment = '0', 
                            deny_inheritance = True, 
                            deny_rotate = True, 
                            depth = 56, 
                            expired_date = '0', 
                            id = '0', 
                            last_rotate = '0', 
                            revoked = True, 
                            ttl = 56, )
                        }, 
                    comment = '0', 
                    deny_inheritance = True, 
                    deny_rotate = True, 
                    depth = 56, 
                    expired_date = '0', 
                    id = '0', 
                    last_rotate = '0', 
                    revoked = True, 
                    ttl = 56, )
            )
        else :
            return UniversalIdentityDetails(
        )

    def testUniversalIdentityDetails(self):
        """Test UniversalIdentityDetails"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CreateKey(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alg': 'str',
        'customer_frg_id': 'str',
        'delete_protection': 'str',
        'json': 'bool',
        'metadata': 'str',
        'name': 'str',
        'split_level': 'int',
        'tag': 'list[str]',
        'token': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'alg': 'alg',
        'customer_frg_id': 'customer-frg-id',
        'delete_protection': 'delete_protection',
        'json': 'json',
        'metadata': 'metadata',
        'name': 'name',
        'split_level': 'split-level',
        'tag': 'tag',
        'token': 'token',
        'uid_token': 'uid-token'
    }

    def __init__(self, alg=None, customer_frg_id=None, delete_protection=None, json=None, metadata=None, name=None, split_level=2, tag=None, token=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """CreateKey - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alg = None
        self._customer_frg_id = None
        self._delete_protection = None
        self._json = None
        self._metadata = None
        self._name = None
        self._split_level = None
        self._tag = None
        self._token = None
        self._uid_token = None
        self.discriminator = None

        self.alg = alg
        if customer_frg_id is not None:
            self.customer_frg_id = customer_frg_id
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if json is not None:
            self.json = json
        if metadata is not None:
            self.metadata = metadata
        self.name = name
        if split_level is not None:
            self.split_level = split_level
        if tag is not None:
            self.tag = tag
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def alg(self):
        """Gets the alg of this CreateKey.  # noqa: E501

        Key type; options: [AES128GCM, AES256GCM, AES128SIV, AES256SIV, AES128CBC, AES256CBC, RSA1024, RSA2048, RSA3072, RSA4096]  # noqa: E501

        :return: The alg of this CreateKey.  # noqa: E501
        :rtype: str
        """
        return self._alg

    @alg.setter
    def alg(self, alg):
        """Sets the alg of this CreateKey.

        Key type; options: [AES128GCM, AES256GCM, AES128SIV, AES256SIV, AES128CBC, AES256CBC, RSA1024, RSA2048, RSA3072, RSA4096]  # noqa: E501

        :param alg: The alg of this CreateKey.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and alg is None:  # noqa: E501
            raise ValueError("Invalid value for `alg`, must not be `None`")  # noqa: E501

        self._alg = alg

    @property
    def customer_frg_id(self):
        """Gets the customer_frg_id of this CreateKey.  # noqa: E501

        The customer fragment ID that will be used to create the key (if empty, the key will be created independently of a customer fragment)  # noqa: E501

        :return: The customer_frg_id of this CreateKey.  # noqa: E501
        :rtype: str
        """
        return self._customer_frg_id

    @customer_frg_id.setter
    def customer_frg_id(self, customer_frg_id):
        """Sets the customer_frg_id of this CreateKey.

        The customer fragment ID that will be used to create the key (if empty, the key will be created independently of a customer fragment)  # noqa: E501

        :param customer_frg_id: The customer_frg_id of this CreateKey.  # noqa: E501
        :type: str
        """

        self._customer_frg_id = customer_frg_id

    @property
    def delete_protection(self):
        """Gets the delete_protection of this CreateKey.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this CreateKey.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this CreateKey.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this CreateKey.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def json(self):
        """Gets the json of this CreateKey.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this CreateKey.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this CreateKey.

        Set output format to JSON  # noqa: E501

        :param json: The json of this CreateKey.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def metadata(self):
        """Gets the metadata of this CreateKey.  # noqa: E501

        Metadata about the key  # noqa: E501

        :return: The metadata of this CreateKey.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this CreateKey.

        Metadata about the key  # noqa: E501

        :param metadata: The metadata of this CreateKey.  # noqa: E501
        :type: str
        """

        self._metadata = metadata

    @property
    def name(self):
        """Gets the name of this CreateKey.  # noqa: E501

        Key name  # noqa: E501

        :return: The name of this CreateKey.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateKey.

        Key name  # noqa: E501

        :param name: The name of this CreateKey.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def split_level(self):
        """Gets the split_level of this CreateKey.  # noqa: E501

        The number of fragments that the item will be split into (not includes customer fragment)  # noqa: E501

        :return: The split_level of this CreateKey.  # noqa: E501
        :rtype: int
        """
        return self._split_level

    @split_level.setter
    def split_level(self, split_level):
        """Sets the split_level of this CreateKey.

        The number of fragments that the item will be split into (not includes customer fragment)  # noqa: E501

        :param split_level: The split_level of this CreateKey.  # noqa: E501
        :type: int
        """

        self._split_level = split_level

    @property
    def tag(self):
        """Gets the tag of this CreateKey.  # noqa: E501

        List of the tags attached to this key  # noqa: E501

        :return: The tag of this CreateKey.  # noqa: E501
        :rtype: list[str]
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this CreateKey.

        List of the tags attached to this key  # noqa: E501

        :param tag: The tag of this CreateKey.  # noqa: E501
        :type: list[str]
        """

        self._tag = tag

    @property
    def token(self):
        """Gets the token of this CreateKey.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this CreateKey.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this CreateKey.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this CreateKey.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this CreateKey.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this CreateKey.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this CreateKey.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this CreateKey.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateKey):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateKey):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.auth_method import AuthMethod  # noqa: E501
from akeyless.rest import ApiException

class TestAuthMethod(unittest.TestCase):
    """AuthMethod unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AuthMethod
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.auth_method.AuthMethod()  # noqa: E501
        if include_optional :
            return AuthMethod(
                access_info = akeyless.models.auth_method_access_info_includes_auth_method_access_information/.AuthMethodAccessInfo includes auth method access information.(
                    access_expires = 56, 
                    api_key_access_rules = akeyless.models.api_key_access_rules_is_a_set_of_rules_for_api_key_access_type/.APIKeyAccessRules is a set of rules for API Key access type.(
                        alg = '0', 
                        key = '0', ), 
                    aws_iam_access_rules = akeyless.models.awsiam_access_rules_contains_access_rules_specific_to_aws_iam/.AWSIAMAccessRules contains access rules specific to AWS IAM.(
                        account_id = [
                            '0'
                            ], 
                        arn = [
                            '0'
                            ], 
                        resource_id = [
                            '0'
                            ], 
                        role_id = [
                            '0'
                            ], 
                        role_name = [
                            '0'
                            ], 
                        sts_endpoint = '0', 
                        user_id = [
                            '0'
                            ], 
                        user_name = [
                            '0'
                            ], ), 
                    azure_ad_access_rules = akeyless.models.azure_ad_access_rules.AzureADAccessRules(
                        ad_endpoint = '0', 
                        bound_group_ids = [
                            '0'
                            ], 
                        bound_resource_groups = [
                            '0'
                            ], 
                        bound_resource_ids = [
                            '0'
                            ], 
                        bound_resource_names = [
                            '0'
                            ], 
                        bound_resource_providers = [
                            '0'
                            ], 
                        bound_resource_types = [
                            '0'
                            ], 
                        bound_service_principal_ids = [
                            '0'
                            ], 
                        bound_subscription_ids = [
                            '0'
                            ], 
                        bound_tenant_id = '0', 
                        issuer = '0', 
                        jwks_uri = '0', ), 
                    cidr_whitelist = '0', 
                    email_pass_access_rules = akeyless.models.email_pass_access_rules_is_a_set_of_rules_for_email_password_access_type/.EmailPassAccessRules is a set of rules for email password access type.(
                        alg = '0', 
                        email = '0', 
                        hash_pass = '0', ), 
                    huawei_access_rules = akeyless.models.huawei_access_rules_defines_access_rules_specific_to_huawei_authentication/.HuaweiAccessRules defines access rules specific to Huawei authentication.(
                        auth_endpoint = '0', 
                        domain_id = [
                            '0'
                            ], 
                        domain_name = [
                            '0'
                            ], 
                        tenant_id = [
                            '0'
                            ], 
                        tenant_name = [
                            '0'
                            ], ), 
                    ldap_access_rules = akeyless.models.ldap_access_rules_includes_access_rules_specific_to_ldap_authentication/.LDAPAccessRules includes access rules specific to LDAP authentication.(
                        key = '0', ), 
                    oauth2_access_rules = akeyless.models.o_auth2_access_rules.OAuth2AccessRules(
                        audience = '0', 
                        bound_claims = [
                            akeyless.models.o_auth2_custom_claim.OAuth2CustomClaim(
                                name = '0', 
                                values = [
                                    '0'
                                    ], )
                            ], 
                        bound_clients_id = [
                            '0'
                            ], 
                        issuer = '0', 
                        jwks_uri = '0', ), 
                    rules_type = '0', 
                    saml_access_rules = akeyless.models.saml_access_rules_defines_access_rules_specific_to_saml_authentication_method/.SAMLAccessRules defines access rules specific to SAML authentication method.(
                        bound_attributes = [
                            akeyless.models.saml_attribute_defines_an_attribute_of_saml_authentication/.SAMLAttribute defines an attribute of SAML authentication.(
                                name = '0', )
                            ], 
                        idp_metadata_url = '0', 
                        idp_metadata_xml = '0', ), 
                    universal_identity_access_rules = akeyless.models.universal_identity_access_rules_contains_access_rules_specific_to_universal_identity/.UniversalIdentityAccessRules contains access rules specific to Universal Identity.(
                        deny_inheritance = True, 
                        deny_rotate = True, 
                        ttl = 56, ), ), 
                account_id = '0', 
                auth_method_access_id = '0', 
                auth_method_name = '0', 
                auth_method_roles_assoc = [
                    akeyless.models.auth_method_role_association.AuthMethodRoleAssociation(
                        assoc_id = '0', 
                        auth_method_sub_claims = {
                            'key' : [
                                '0'
                                ]
                            }, 
                        role_name = '0', 
                        rules = akeyless.models.rules_are_a_part_of_akeyless_rbac/.Rules are a part of AKEYLESS RBAC.(
                            admin = True, 
                            path_rules = [
                                akeyless.models.path_rule_is_a_single_rule_used_in_akeyless_rbac/.PathRule is a single rule used in AKEYLESS RBAC.(
                                    capabilities = [
                                        '0'
                                        ], 
                                    path = '0', 
                                    type = '0', )
                                ], ), )
                    ], 
                client_permissions = [
                    '0'
                    ]
            )
        else :
            return AuthMethod(
        )

    def testAuthMethod(self):
        """Test AuthMethod"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.ssh_certificate_issue_details import SSHCertificateIssueDetails  # noqa: E501
from akeyless.rest import ApiException

class TestSSHCertificateIssueDetails(unittest.TestCase):
    """SSHCertificateIssueDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SSHCertificateIssueDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.ssh_certificate_issue_details.SSHCertificateIssueDetails()  # noqa: E501
        if include_optional :
            return SSHCertificateIssueDetails(
                allowed_domains = [
                    '0'
                    ], 
                allowed_user_key_lengths = {
                    'key' : 56
                    }, 
                allowed_users = [
                    '0'
                    ], 
                cert_type = 56, 
                critical_options = {
                    'key' : '0'
                    }, 
                extensions = {
                    'key' : '0'
                    }, 
                principals = [
                    '0'
                    ], 
                static_key_id = '0'
            )
        else :
            return SSHCertificateIssueDetails(
        )

    def testSSHCertificateIssueDetails(self):
        """Test SSHCertificateIssueDetails"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'accessibility': 'str',
        'add_tag': 'list[str]',
        'cert_file_data': 'str',
        'delete_protection': 'str',
        'json': 'bool',
        'name': 'str',
        'new_metadata': 'str',
        'new_name': 'str',
        'rm_tag': 'list[str]',
        'secure_access_add_host': 'list[str]',
        'secure_access_allow_external_user': 'str',
        'secure_access_allow_port_forwading': 'bool',
        'secure_access_aws_account_id': 'str',
        'secure_access_aws_native_cli': 'bool',
        'secure_access_aws_region': 'str',
        'secure_access_bastion_api': 'str',
        'secure_access_bastion_issuer': 'str',
        'secure_access_bastion_ssh': 'str',
        'secure_access_cluster_endpoint': 'str',
        'secure_access_dashboard_url': 'str',
        'secure_access_db_name': 'str',
        'secure_access_db_schema': 'str',
        'secure_access_enable': 'str',
        'secure_access_host': 'list[str]',
        'secure_access_rdp_domain': 'str',
        'secure_access_rdp_user': 'str',
        'secure_access_rm_host': 'list[str]',
        'secure_access_ssh_creds': 'str',
        'secure_access_ssh_creds_user': 'str',
        'secure_access_url': 'str',
        'secure_access_use_internal_bastion': 'bool',
        'secure_access_web_browsing': 'bool',
        'secure_access_web_proxy': 'bool',
        'token': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'accessibility': 'accessibility',
        'add_tag': 'add-tag',
        'cert_file_data': 'cert-file-data',
        'delete_protection': 'delete_protection',
        'json': 'json',
        'name': 'name',
        'new_metadata': 'new-metadata',
        'new_name': 'new-name',
        'rm_tag': 'rm-tag',
        'secure_access_add_host': 'secure-access-add-host',
        'secure_access_allow_external_user': 'secure-access-allow-external-user',
        'secure_access_allow_port_forwading': 'secure-access-allow-port-forwading',
        'secure_access_aws_account_id': 'secure-access-aws-account-id',
        'secure_access_aws_native_cli': 'secure-access-aws-native-cli',
        'secure_access_aws_region': 'secure-access-aws-region',
        'secure_access_bastion_api': 'secure-access-bastion-api',
        'secure_access_bastion_issuer': 'secure-access-bastion-issuer',
        'secure_access_bastion_ssh': 'secure-access-bastion-ssh',
        'secure_access_cluster_endpoint': 'secure-access-cluster-endpoint',
        'secure_access_dashboard_url': 'secure-access-dashboard-url',
        'secure_access_db_name': 'secure-access-db-name',
        'secure_access_db_schema': 'secure-access-db-schema',
        'secure_access_enable': 'secure-access-enable',
        'secure_access_host': 'secure-access-host',
        'secure_access_rdp_domain': 'secure-access-rdp-domain',
        'secure_access_rdp_user': 'secure-access-rdp-user',
        'secure_access_rm_host': 'secure-access-rm-host',
        'secure_access_ssh_creds': 'secure-access-ssh-creds',
        'secure_access_ssh_creds_user': 'secure-access-ssh-creds-user',
        'secure_access_url': 'secure-access-url',
        'secure_access_use_internal_bastion': 'secure-access-use-internal-bastion',
        'secure_access_web_browsing': 'secure-access-web-browsing',
        'secure_access_web_proxy': 'secure-access-web-proxy',
        'token': 'token',
        'uid_token': 'uid-token'
    }

    def __init__(self, accessibility='regular', add_tag=None, cert_file_data=None, delete_protection=None, json=None, name=None, new_metadata='default_metadata', new_name=None, rm_tag=None, secure_access_add_host=None, secure_access_allow_external_user=None, secure_access_allow_port_forwading=None, secure_access_aws_account_id=None, secure_access_aws_native_cli=None, secure_access_aws_region=None, secure_access_bastion_api=None, secure_access_bastion_issuer=None, secure_access_bastion_ssh=None, secure_access_cluster_endpoint=None, secure_access_dashboard_url=None, secure_access_db_name=None, secure_access_db_schema=None, secure_access_enable=None, secure_access_host=None, secure_access_rdp_domain=None, secure_access_rdp_user=None, secure_access_rm_host=None, secure_access_ssh_creds=None, secure_access_ssh_creds_user=None, secure_access_url=None, secure_access_use_internal_bastion=None, secure_access_web_browsing=None, secure_access_web_proxy=None, token=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """UpdateItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._accessibility = None
        self._add_tag = None
        self._cert_file_data = None
        self._delete_protection = None
        self._json = None
        self._name = None
        self._new_metadata = None
        self._new_name = None
        self._rm_tag = None
        self._secure_access_add_host = None
        self._secure_access_allow_external_user = None
        self._secure_access_allow_port_forwading = None
        self._secure_access_aws_account_id = None
        self._secure_access_aws_native_cli = None
        self._secure_access_aws_region = None
        self._secure_access_bastion_api = None
        self._secure_access_bastion_issuer = None
        self._secure_access_bastion_ssh = None
        self._secure_access_cluster_endpoint = None
        self._secure_access_dashboard_url = None
        self._secure_access_db_name = None
        self._secure_access_db_schema = None
        self._secure_access_enable = None
        self._secure_access_host = None
        self._secure_access_rdp_domain = None
        self._secure_access_rdp_user = None
        self._secure_access_rm_host = None
        self._secure_access_ssh_creds = None
        self._secure_access_ssh_creds_user = None
        self._secure_access_url = None
        self._secure_access_use_internal_bastion = None
        self._secure_access_web_browsing = None
        self._secure_access_web_proxy = None
        self._token = None
        self._uid_token = None
        self.discriminator = None

        if accessibility is not None:
            self.accessibility = accessibility
        if add_tag is not None:
            self.add_tag = add_tag
        if cert_file_data is not None:
            self.cert_file_data = cert_file_data
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if json is not None:
            self.json = json
        self.name = name
        if new_metadata is not None:
            self.new_metadata = new_metadata
        if new_name is not None:
            self.new_name = new_name
        if rm_tag is not None:
            self.rm_tag = rm_tag
        if secure_access_add_host is not None:
            self.secure_access_add_host = secure_access_add_host
        if secure_access_allow_external_user is not None:
            self.secure_access_allow_external_user = secure_access_allow_external_user
        if secure_access_allow_port_forwading is not None:
            self.secure_access_allow_port_forwading = secure_access_allow_port_forwading
        if secure_access_aws_account_id is not None:
            self.secure_access_aws_account_id = secure_access_aws_account_id
        if secure_access_aws_native_cli is not None:
            self.secure_access_aws_native_cli = secure_access_aws_native_cli
        if secure_access_aws_region is not None:
            self.secure_access_aws_region = secure_access_aws_region
        if secure_access_bastion_api is not None:
            self.secure_access_bastion_api = secure_access_bastion_api
        if secure_access_bastion_issuer is not None:
            self.secure_access_bastion_issuer = secure_access_bastion_issuer
        if secure_access_bastion_ssh is not None:
            self.secure_access_bastion_ssh = secure_access_bastion_ssh
        if secure_access_cluster_endpoint is not None:
            self.secure_access_cluster_endpoint = secure_access_cluster_endpoint
        if secure_access_dashboard_url is not None:
            self.secure_access_dashboard_url = secure_access_dashboard_url
        if secure_access_db_name is not None:
            self.secure_access_db_name = secure_access_db_name
        if secure_access_db_schema is not None:
            self.secure_access_db_schema = secure_access_db_schema
        if secure_access_enable is not None:
            self.secure_access_enable = secure_access_enable
        if secure_access_host is not None:
            self.secure_access_host = secure_access_host
        if secure_access_rdp_domain is not None:
            self.secure_access_rdp_domain = secure_access_rdp_domain
        if secure_access_rdp_user is not None:
            self.secure_access_rdp_user = secure_access_rdp_user
        if secure_access_rm_host is not None:
            self.secure_access_rm_host = secure_access_rm_host
        if secure_access_ssh_creds is not None:
            self.secure_access_ssh_creds = secure_access_ssh_creds
        if secure_access_ssh_creds_user is not None:
            self.secure_access_ssh_creds_user = secure_access_ssh_creds_user
        if secure_access_url is not None:
            self.secure_access_url = secure_access_url
        if secure_access_use_internal_bastion is not None:
            self.secure_access_use_internal_bastion = secure_access_use_internal_bastion
        if secure_access_web_browsing is not None:
            self.secure_access_web_browsing = secure_access_web_browsing
        if secure_access_web_proxy is not None:
            self.secure_access_web_proxy = secure_access_web_proxy
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def accessibility(self):
        """Gets the accessibility of this UpdateItem.  # noqa: E501

        for personal password manager  # noqa: E501

        :return: The accessibility of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._accessibility

    @accessibility.setter
    def accessibility(self, accessibility):
        """Sets the accessibility of this UpdateItem.

        for personal password manager  # noqa: E501

        :param accessibility: The accessibility of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._accessibility = accessibility

    @property
    def add_tag(self):
        """Gets the add_tag of this UpdateItem.  # noqa: E501

        List of the new tags that will be attached to this item  # noqa: E501

        :return: The add_tag of this UpdateItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._add_tag

    @add_tag.setter
    def add_tag(self, add_tag):
        """Sets the add_tag of this UpdateItem.

        List of the new tags that will be attached to this item  # noqa: E501

        :param add_tag: The add_tag of this UpdateItem.  # noqa: E501
        :type: list[str]
        """

        self._add_tag = add_tag

    @property
    def cert_file_data(self):
        """Gets the cert_file_data of this UpdateItem.  # noqa: E501

        PEM Certificate in a Base64 format. Used for updating RSA keys' certificates.  # noqa: E501

        :return: The cert_file_data of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._cert_file_data

    @cert_file_data.setter
    def cert_file_data(self, cert_file_data):
        """Sets the cert_file_data of this UpdateItem.

        PEM Certificate in a Base64 format. Used for updating RSA keys' certificates.  # noqa: E501

        :param cert_file_data: The cert_file_data of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._cert_file_data = cert_file_data

    @property
    def delete_protection(self):
        """Gets the delete_protection of this UpdateItem.  # noqa: E501


        :return: The delete_protection of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this UpdateItem.


        :param delete_protection: The delete_protection of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def json(self):
        """Gets the json of this UpdateItem.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UpdateItem.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UpdateItem.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UpdateItem.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this UpdateItem.  # noqa: E501

        Current item name  # noqa: E501

        :return: The name of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateItem.

        Current item name  # noqa: E501

        :param name: The name of this UpdateItem.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_metadata(self):
        """Gets the new_metadata of this UpdateItem.  # noqa: E501

        New item metadata  # noqa: E501

        :return: The new_metadata of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._new_metadata

    @new_metadata.setter
    def new_metadata(self, new_metadata):
        """Sets the new_metadata of this UpdateItem.

        New item metadata  # noqa: E501

        :param new_metadata: The new_metadata of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._new_metadata = new_metadata

    @property
    def new_name(self):
        """Gets the new_name of this UpdateItem.  # noqa: E501

        New item name  # noqa: E501

        :return: The new_name of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this UpdateItem.

        New item name  # noqa: E501

        :param new_name: The new_name of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def rm_tag(self):
        """Gets the rm_tag of this UpdateItem.  # noqa: E501

        List of the existent tags that will be removed from this item  # noqa: E501

        :return: The rm_tag of this UpdateItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._rm_tag

    @rm_tag.setter
    def rm_tag(self, rm_tag):
        """Sets the rm_tag of this UpdateItem.

        List of the existent tags that will be removed from this item  # noqa: E501

        :param rm_tag: The rm_tag of this UpdateItem.  # noqa: E501
        :type: list[str]
        """

        self._rm_tag = rm_tag

    @property
    def secure_access_add_host(self):
        """Gets the secure_access_add_host of this UpdateItem.  # noqa: E501


        :return: The secure_access_add_host of this UpdateItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._secure_access_add_host

    @secure_access_add_host.setter
    def secure_access_add_host(self, secure_access_add_host):
        """Sets the secure_access_add_host of this UpdateItem.


        :param secure_access_add_host: The secure_access_add_host of this UpdateItem.  # noqa: E501
        :type: list[str]
        """

        self._secure_access_add_host = secure_access_add_host

    @property
    def secure_access_allow_external_user(self):
        """Gets the secure_access_allow_external_user of this UpdateItem.  # noqa: E501


        :return: The secure_access_allow_external_user of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_allow_external_user

    @secure_access_allow_external_user.setter
    def secure_access_allow_external_user(self, secure_access_allow_external_user):
        """Sets the secure_access_allow_external_user of this UpdateItem.


        :param secure_access_allow_external_user: The secure_access_allow_external_user of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_allow_external_user = secure_access_allow_external_user

    @property
    def secure_access_allow_port_forwading(self):
        """Gets the secure_access_allow_port_forwading of this UpdateItem.  # noqa: E501


        :return: The secure_access_allow_port_forwading of this UpdateItem.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_allow_port_forwading

    @secure_access_allow_port_forwading.setter
    def secure_access_allow_port_forwading(self, secure_access_allow_port_forwading):
        """Sets the secure_access_allow_port_forwading of this UpdateItem.


        :param secure_access_allow_port_forwading: The secure_access_allow_port_forwading of this UpdateItem.  # noqa: E501
        :type: bool
        """

        self._secure_access_allow_port_forwading = secure_access_allow_port_forwading

    @property
    def secure_access_aws_account_id(self):
        """Gets the secure_access_aws_account_id of this UpdateItem.  # noqa: E501


        :return: The secure_access_aws_account_id of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_aws_account_id

    @secure_access_aws_account_id.setter
    def secure_access_aws_account_id(self, secure_access_aws_account_id):
        """Sets the secure_access_aws_account_id of this UpdateItem.


        :param secure_access_aws_account_id: The secure_access_aws_account_id of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_aws_account_id = secure_access_aws_account_id

    @property
    def secure_access_aws_native_cli(self):
        """Gets the secure_access_aws_native_cli of this UpdateItem.  # noqa: E501


        :return: The secure_access_aws_native_cli of this UpdateItem.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_aws_native_cli

    @secure_access_aws_native_cli.setter
    def secure_access_aws_native_cli(self, secure_access_aws_native_cli):
        """Sets the secure_access_aws_native_cli of this UpdateItem.


        :param secure_access_aws_native_cli: The secure_access_aws_native_cli of this UpdateItem.  # noqa: E501
        :type: bool
        """

        self._secure_access_aws_native_cli = secure_access_aws_native_cli

    @property
    def secure_access_aws_region(self):
        """Gets the secure_access_aws_region of this UpdateItem.  # noqa: E501


        :return: The secure_access_aws_region of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_aws_region

    @secure_access_aws_region.setter
    def secure_access_aws_region(self, secure_access_aws_region):
        """Sets the secure_access_aws_region of this UpdateItem.


        :param secure_access_aws_region: The secure_access_aws_region of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_aws_region = secure_access_aws_region

    @property
    def secure_access_bastion_api(self):
        """Gets the secure_access_bastion_api of this UpdateItem.  # noqa: E501


        :return: The secure_access_bastion_api of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_bastion_api

    @secure_access_bastion_api.setter
    def secure_access_bastion_api(self, secure_access_bastion_api):
        """Sets the secure_access_bastion_api of this UpdateItem.


        :param secure_access_bastion_api: The secure_access_bastion_api of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_bastion_api = secure_access_bastion_api

    @property
    def secure_access_bastion_issuer(self):
        """Gets the secure_access_bastion_issuer of this UpdateItem.  # noqa: E501


        :return: The secure_access_bastion_issuer of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_bastion_issuer

    @secure_access_bastion_issuer.setter
    def secure_access_bastion_issuer(self, secure_access_bastion_issuer):
        """Sets the secure_access_bastion_issuer of this UpdateItem.


        :param secure_access_bastion_issuer: The secure_access_bastion_issuer of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_bastion_issuer = secure_access_bastion_issuer

    @property
    def secure_access_bastion_ssh(self):
        """Gets the secure_access_bastion_ssh of this UpdateItem.  # noqa: E501


        :return: The secure_access_bastion_ssh of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_bastion_ssh

    @secure_access_bastion_ssh.setter
    def secure_access_bastion_ssh(self, secure_access_bastion_ssh):
        """Sets the secure_access_bastion_ssh of this UpdateItem.


        :param secure_access_bastion_ssh: The secure_access_bastion_ssh of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_bastion_ssh = secure_access_bastion_ssh

    @property
    def secure_access_cluster_endpoint(self):
        """Gets the secure_access_cluster_endpoint of this UpdateItem.  # noqa: E501


        :return: The secure_access_cluster_endpoint of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_cluster_endpoint

    @secure_access_cluster_endpoint.setter
    def secure_access_cluster_endpoint(self, secure_access_cluster_endpoint):
        """Sets the secure_access_cluster_endpoint of this UpdateItem.


        :param secure_access_cluster_endpoint: The secure_access_cluster_endpoint of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_cluster_endpoint = secure_access_cluster_endpoint

    @property
    def secure_access_dashboard_url(self):
        """Gets the secure_access_dashboard_url of this UpdateItem.  # noqa: E501


        :return: The secure_access_dashboard_url of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_dashboard_url

    @secure_access_dashboard_url.setter
    def secure_access_dashboard_url(self, secure_access_dashboard_url):
        """Sets the secure_access_dashboard_url of this UpdateItem.


        :param secure_access_dashboard_url: The secure_access_dashboard_url of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_dashboard_url = secure_access_dashboard_url

    @property
    def secure_access_db_name(self):
        """Gets the secure_access_db_name of this UpdateItem.  # noqa: E501


        :return: The secure_access_db_name of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_db_name

    @secure_access_db_name.setter
    def secure_access_db_name(self, secure_access_db_name):
        """Sets the secure_access_db_name of this UpdateItem.


        :param secure_access_db_name: The secure_access_db_name of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_db_name = secure_access_db_name

    @property
    def secure_access_db_schema(self):
        """Gets the secure_access_db_schema of this UpdateItem.  # noqa: E501


        :return: The secure_access_db_schema of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_db_schema

    @secure_access_db_schema.setter
    def secure_access_db_schema(self, secure_access_db_schema):
        """Sets the secure_access_db_schema of this UpdateItem.


        :param secure_access_db_schema: The secure_access_db_schema of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_db_schema = secure_access_db_schema

    @property
    def secure_access_enable(self):
        """Gets the secure_access_enable of this UpdateItem.  # noqa: E501


        :return: The secure_access_enable of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_enable

    @secure_access_enable.setter
    def secure_access_enable(self, secure_access_enable):
        """Sets the secure_access_enable of this UpdateItem.


        :param secure_access_enable: The secure_access_enable of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_enable = secure_access_enable

    @property
    def secure_access_host(self):
        """Gets the secure_access_host of this UpdateItem.  # noqa: E501


        :return: The secure_access_host of this UpdateItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._secure_access_host

    @secure_access_host.setter
    def secure_access_host(self, secure_access_host):
        """Sets the secure_access_host of this UpdateItem.


        :param secure_access_host: The secure_access_host of this UpdateItem.  # noqa: E501
        :type: list[str]
        """

        self._secure_access_host = secure_access_host

    @property
    def secure_access_rdp_domain(self):
        """Gets the secure_access_rdp_domain of this UpdateItem.  # noqa: E501


        :return: The secure_access_rdp_domain of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_rdp_domain

    @secure_access_rdp_domain.setter
    def secure_access_rdp_domain(self, secure_access_rdp_domain):
        """Sets the secure_access_rdp_domain of this UpdateItem.


        :param secure_access_rdp_domain: The secure_access_rdp_domain of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_rdp_domain = secure_access_rdp_domain

    @property
    def secure_access_rdp_user(self):
        """Gets the secure_access_rdp_user of this UpdateItem.  # noqa: E501


        :return: The secure_access_rdp_user of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_rdp_user

    @secure_access_rdp_user.setter
    def secure_access_rdp_user(self, secure_access_rdp_user):
        """Sets the secure_access_rdp_user of this UpdateItem.


        :param secure_access_rdp_user: The secure_access_rdp_user of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_rdp_user = secure_access_rdp_user

    @property
    def secure_access_rm_host(self):
        """Gets the secure_access_rm_host of this UpdateItem.  # noqa: E501


        :return: The secure_access_rm_host of this UpdateItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._secure_access_rm_host

    @secure_access_rm_host.setter
    def secure_access_rm_host(self, secure_access_rm_host):
        """Sets the secure_access_rm_host of this UpdateItem.


        :param secure_access_rm_host: The secure_access_rm_host of this UpdateItem.  # noqa: E501
        :type: list[str]
        """

        self._secure_access_rm_host = secure_access_rm_host

    @property
    def secure_access_ssh_creds(self):
        """Gets the secure_access_ssh_creds of this UpdateItem.  # noqa: E501


        :return: The secure_access_ssh_creds of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_ssh_creds

    @secure_access_ssh_creds.setter
    def secure_access_ssh_creds(self, secure_access_ssh_creds):
        """Sets the secure_access_ssh_creds of this UpdateItem.


        :param secure_access_ssh_creds: The secure_access_ssh_creds of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_ssh_creds = secure_access_ssh_creds

    @property
    def secure_access_ssh_creds_user(self):
        """Gets the secure_access_ssh_creds_user of this UpdateItem.  # noqa: E501


        :return: The secure_access_ssh_creds_user of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_ssh_creds_user

    @secure_access_ssh_creds_user.setter
    def secure_access_ssh_creds_user(self, secure_access_ssh_creds_user):
        """Sets the secure_access_ssh_creds_user of this UpdateItem.


        :param secure_access_ssh_creds_user: The secure_access_ssh_creds_user of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_ssh_creds_user = secure_access_ssh_creds_user

    @property
    def secure_access_url(self):
        """Gets the secure_access_url of this UpdateItem.  # noqa: E501


        :return: The secure_access_url of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_url

    @secure_access_url.setter
    def secure_access_url(self, secure_access_url):
        """Sets the secure_access_url of this UpdateItem.


        :param secure_access_url: The secure_access_url of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._secure_access_url = secure_access_url

    @property
    def secure_access_use_internal_bastion(self):
        """Gets the secure_access_use_internal_bastion of this UpdateItem.  # noqa: E501


        :return: The secure_access_use_internal_bastion of this UpdateItem.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_use_internal_bastion

    @secure_access_use_internal_bastion.setter
    def secure_access_use_internal_bastion(self, secure_access_use_internal_bastion):
        """Sets the secure_access_use_internal_bastion of this UpdateItem.


        :param secure_access_use_internal_bastion: The secure_access_use_internal_bastion of this UpdateItem.  # noqa: E501
        :type: bool
        """

        self._secure_access_use_internal_bastion = secure_access_use_internal_bastion

    @property
    def secure_access_web_browsing(self):
        """Gets the secure_access_web_browsing of this UpdateItem.  # noqa: E501


        :return: The secure_access_web_browsing of this UpdateItem.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web_browsing

    @secure_access_web_browsing.setter
    def secure_access_web_browsing(self, secure_access_web_browsing):
        """Sets the secure_access_web_browsing of this UpdateItem.


        :param secure_access_web_browsing: The secure_access_web_browsing of this UpdateItem.  # noqa: E501
        :type: bool
        """

        self._secure_access_web_browsing = secure_access_web_browsing

    @property
    def secure_access_web_proxy(self):
        """Gets the secure_access_web_proxy of this UpdateItem.  # noqa: E501


        :return: The secure_access_web_proxy of this UpdateItem.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web_proxy

    @secure_access_web_proxy.setter
    def secure_access_web_proxy(self, secure_access_web_proxy):
        """Sets the secure_access_web_proxy of this UpdateItem.


        :param secure_access_web_proxy: The secure_access_web_proxy of this UpdateItem.  # noqa: E501
        :type: bool
        """

        self._secure_access_web_proxy = secure_access_web_proxy

    @property
    def token(self):
        """Gets the token of this UpdateItem.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateItem.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateItem.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateItem.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateItem.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateItem.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GeneralConfigPart(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'akeyless_url': 'str',
        'api_token_ttl': 'str',
        'display_name': 'str',
        'enable_tls': 'bool',
        'enable_tls_configure': 'bool',
        'enable_tls_curl': 'bool',
        'enable_tls_hvp': 'bool',
        'gw_cluster_url': 'str',
        'tcp_port': 'str',
        'tls_cert': 'str',
        'tls_key': 'str'
    }

    attribute_map = {
        'akeyless_url': 'akeyless_url',
        'api_token_ttl': 'api_token_ttl',
        'display_name': 'display_name',
        'enable_tls': 'enable_tls',
        'enable_tls_configure': 'enable_tls_configure',
        'enable_tls_curl': 'enable_tls_curl',
        'enable_tls_hvp': 'enable_tls_hvp',
        'gw_cluster_url': 'gw_cluster_url',
        'tcp_port': 'tcp_port',
        'tls_cert': 'tls_cert',
        'tls_key': 'tls_key'
    }

    def __init__(self, akeyless_url=None, api_token_ttl=None, display_name=None, enable_tls=None, enable_tls_configure=None, enable_tls_curl=None, enable_tls_hvp=None, gw_cluster_url=None, tcp_port=None, tls_cert=None, tls_key=None, local_vars_configuration=None):  # noqa: E501
        """GeneralConfigPart - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._akeyless_url = None
        self._api_token_ttl = None
        self._display_name = None
        self._enable_tls = None
        self._enable_tls_configure = None
        self._enable_tls_curl = None
        self._enable_tls_hvp = None
        self._gw_cluster_url = None
        self._tcp_port = None
        self._tls_cert = None
        self._tls_key = None
        self.discriminator = None

        if akeyless_url is not None:
            self.akeyless_url = akeyless_url
        if api_token_ttl is not None:
            self.api_token_ttl = api_token_ttl
        if display_name is not None:
            self.display_name = display_name
        if enable_tls is not None:
            self.enable_tls = enable_tls
        if enable_tls_configure is not None:
            self.enable_tls_configure = enable_tls_configure
        if enable_tls_curl is not None:
            self.enable_tls_curl = enable_tls_curl
        if enable_tls_hvp is not None:
            self.enable_tls_hvp = enable_tls_hvp
        if gw_cluster_url is not None:
            self.gw_cluster_url = gw_cluster_url
        if tcp_port is not None:
            self.tcp_port = tcp_port
        if tls_cert is not None:
            self.tls_cert = tls_cert
        if tls_key is not None:
            self.tls_key = tls_key

    @property
    def akeyless_url(self):
        """Gets the akeyless_url of this GeneralConfigPart.  # noqa: E501

        AkeylessUrl is here for BC only. Gator will still return it if it exists in the configuration, but new clients (>=2.34.0) will ignore it and override it with what exists in their local file. It will no longer be sent to Gator for update, so new clusters will only have the default value saved in the DB.  # noqa: E501

        :return: The akeyless_url of this GeneralConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._akeyless_url

    @akeyless_url.setter
    def akeyless_url(self, akeyless_url):
        """Sets the akeyless_url of this GeneralConfigPart.

        AkeylessUrl is here for BC only. Gator will still return it if it exists in the configuration, but new clients (>=2.34.0) will ignore it and override it with what exists in their local file. It will no longer be sent to Gator for update, so new clusters will only have the default value saved in the DB.  # noqa: E501

        :param akeyless_url: The akeyless_url of this GeneralConfigPart.  # noqa: E501
        :type: str
        """

        self._akeyless_url = akeyless_url

    @property
    def api_token_ttl(self):
        """Gets the api_token_ttl of this GeneralConfigPart.  # noqa: E501


        :return: The api_token_ttl of this GeneralConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._api_token_ttl

    @api_token_ttl.setter
    def api_token_ttl(self, api_token_ttl):
        """Sets the api_token_ttl of this GeneralConfigPart.


        :param api_token_ttl: The api_token_ttl of this GeneralConfigPart.  # noqa: E501
        :type: str
        """

        self._api_token_ttl = api_token_ttl

    @property
    def display_name(self):
        """Gets the display_name of this GeneralConfigPart.  # noqa: E501


        :return: The display_name of this GeneralConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this GeneralConfigPart.


        :param display_name: The display_name of this GeneralConfigPart.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def enable_tls(self):
        """Gets the enable_tls of this GeneralConfigPart.  # noqa: E501


        :return: The enable_tls of this GeneralConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._enable_tls

    @enable_tls.setter
    def enable_tls(self, enable_tls):
        """Sets the enable_tls of this GeneralConfigPart.


        :param enable_tls: The enable_tls of this GeneralConfigPart.  # noqa: E501
        :type: bool
        """

        self._enable_tls = enable_tls

    @property
    def enable_tls_configure(self):
        """Gets the enable_tls_configure of this GeneralConfigPart.  # noqa: E501


        :return: The enable_tls_configure of this GeneralConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._enable_tls_configure

    @enable_tls_configure.setter
    def enable_tls_configure(self, enable_tls_configure):
        """Sets the enable_tls_configure of this GeneralConfigPart.


        :param enable_tls_configure: The enable_tls_configure of this GeneralConfigPart.  # noqa: E501
        :type: bool
        """

        self._enable_tls_configure = enable_tls_configure

    @property
    def enable_tls_curl(self):
        """Gets the enable_tls_curl of this GeneralConfigPart.  # noqa: E501


        :return: The enable_tls_curl of this GeneralConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._enable_tls_curl

    @enable_tls_curl.setter
    def enable_tls_curl(self, enable_tls_curl):
        """Sets the enable_tls_curl of this GeneralConfigPart.


        :param enable_tls_curl: The enable_tls_curl of this GeneralConfigPart.  # noqa: E501
        :type: bool
        """

        self._enable_tls_curl = enable_tls_curl

    @property
    def enable_tls_hvp(self):
        """Gets the enable_tls_hvp of this GeneralConfigPart.  # noqa: E501


        :return: The enable_tls_hvp of this GeneralConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._enable_tls_hvp

    @enable_tls_hvp.setter
    def enable_tls_hvp(self, enable_tls_hvp):
        """Sets the enable_tls_hvp of this GeneralConfigPart.


        :param enable_tls_hvp: The enable_tls_hvp of this GeneralConfigPart.  # noqa: E501
        :type: bool
        """

        self._enable_tls_hvp = enable_tls_hvp

    @property
    def gw_cluster_url(self):
        """Gets the gw_cluster_url of this GeneralConfigPart.  # noqa: E501


        :return: The gw_cluster_url of this GeneralConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._gw_cluster_url

    @gw_cluster_url.setter
    def gw_cluster_url(self, gw_cluster_url):
        """Sets the gw_cluster_url of this GeneralConfigPart.


        :param gw_cluster_url: The gw_cluster_url of this GeneralConfigPart.  # noqa: E501
        :type: str
        """

        self._gw_cluster_url = gw_cluster_url

    @property
    def tcp_port(self):
        """Gets the tcp_port of this GeneralConfigPart.  # noqa: E501


        :return: The tcp_port of this GeneralConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._tcp_port

    @tcp_port.setter
    def tcp_port(self, tcp_port):
        """Sets the tcp_port of this GeneralConfigPart.


        :param tcp_port: The tcp_port of this GeneralConfigPart.  # noqa: E501
        :type: str
        """

        self._tcp_port = tcp_port

    @property
    def tls_cert(self):
        """Gets the tls_cert of this GeneralConfigPart.  # noqa: E501


        :return: The tls_cert of this GeneralConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._tls_cert

    @tls_cert.setter
    def tls_cert(self, tls_cert):
        """Sets the tls_cert of this GeneralConfigPart.


        :param tls_cert: The tls_cert of this GeneralConfigPart.  # noqa: E501
        :type: str
        """

        self._tls_cert = tls_cert

    @property
    def tls_key(self):
        """Gets the tls_key of this GeneralConfigPart.  # noqa: E501


        :return: The tls_key of this GeneralConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._tls_key

    @tls_key.setter
    def tls_key(self, tls_key):
        """Sets the tls_key of this GeneralConfigPart.


        :param tls_key: The tls_key of this GeneralConfigPart.  # noqa: E501
        :type: str
        """

        self._tls_key = tls_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GeneralConfigPart):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GeneralConfigPart):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CertAccessRules(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bound_common_names': 'list[str]',
        'bound_dns_sans': 'list[str]',
        'bound_email_sans': 'list[str]',
        'bound_extensions': 'list[str]',
        'bound_organizational_units': 'list[str]',
        'bound_uri_sans': 'list[str]',
        'certificate': 'str',
        'revoked_cert_ids': 'list[str]',
        'unique_identifier': 'str'
    }

    attribute_map = {
        'bound_common_names': 'bound_common_names',
        'bound_dns_sans': 'bound_dns_sans',
        'bound_email_sans': 'bound_email_sans',
        'bound_extensions': 'bound_extensions',
        'bound_organizational_units': 'bound_organizational_units',
        'bound_uri_sans': 'bound_uri_sans',
        'certificate': 'certificate',
        'revoked_cert_ids': 'revoked_cert_ids',
        'unique_identifier': 'unique_identifier'
    }

    def __init__(self, bound_common_names=None, bound_dns_sans=None, bound_email_sans=None, bound_extensions=None, bound_organizational_units=None, bound_uri_sans=None, certificate=None, revoked_cert_ids=None, unique_identifier=None, local_vars_configuration=None):  # noqa: E501
        """CertAccessRules - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bound_common_names = None
        self._bound_dns_sans = None
        self._bound_email_sans = None
        self._bound_extensions = None
        self._bound_organizational_units = None
        self._bound_uri_sans = None
        self._certificate = None
        self._revoked_cert_ids = None
        self._unique_identifier = None
        self.discriminator = None

        if bound_common_names is not None:
            self.bound_common_names = bound_common_names
        if bound_dns_sans is not None:
            self.bound_dns_sans = bound_dns_sans
        if bound_email_sans is not None:
            self.bound_email_sans = bound_email_sans
        if bound_extensions is not None:
            self.bound_extensions = bound_extensions
        if bound_organizational_units is not None:
            self.bound_organizational_units = bound_organizational_units
        if bound_uri_sans is not None:
            self.bound_uri_sans = bound_uri_sans
        if certificate is not None:
            self.certificate = certificate
        if revoked_cert_ids is not None:
            self.revoked_cert_ids = revoked_cert_ids
        if unique_identifier is not None:
            self.unique_identifier = unique_identifier

    @property
    def bound_common_names(self):
        """Gets the bound_common_names of this CertAccessRules.  # noqa: E501

        A list of names. At least one must exist in the Common Name. Supports globbing.  # noqa: E501

        :return: The bound_common_names of this CertAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_common_names

    @bound_common_names.setter
    def bound_common_names(self, bound_common_names):
        """Sets the bound_common_names of this CertAccessRules.

        A list of names. At least one must exist in the Common Name. Supports globbing.  # noqa: E501

        :param bound_common_names: The bound_common_names of this CertAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_common_names = bound_common_names

    @property
    def bound_dns_sans(self):
        """Gets the bound_dns_sans of this CertAccessRules.  # noqa: E501

        A list of DNS names. At least one must exist in the SANs. Supports globbing.  # noqa: E501

        :return: The bound_dns_sans of this CertAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_dns_sans

    @bound_dns_sans.setter
    def bound_dns_sans(self, bound_dns_sans):
        """Sets the bound_dns_sans of this CertAccessRules.

        A list of DNS names. At least one must exist in the SANs. Supports globbing.  # noqa: E501

        :param bound_dns_sans: The bound_dns_sans of this CertAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_dns_sans = bound_dns_sans

    @property
    def bound_email_sans(self):
        """Gets the bound_email_sans of this CertAccessRules.  # noqa: E501

        A list of Email Addresses. At least one must exist in the SANs. Supports globbing.  # noqa: E501

        :return: The bound_email_sans of this CertAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_email_sans

    @bound_email_sans.setter
    def bound_email_sans(self, bound_email_sans):
        """Sets the bound_email_sans of this CertAccessRules.

        A list of Email Addresses. At least one must exist in the SANs. Supports globbing.  # noqa: E501

        :param bound_email_sans: The bound_email_sans of this CertAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_email_sans = bound_email_sans

    @property
    def bound_extensions(self):
        """Gets the bound_extensions of this CertAccessRules.  # noqa: E501

        A list of extensions formatted as \"oid:value\". Expects the extension value to be some type of ASN1 encoded string. All values must match. Supports globbing on \"value\".  # noqa: E501

        :return: The bound_extensions of this CertAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_extensions

    @bound_extensions.setter
    def bound_extensions(self, bound_extensions):
        """Sets the bound_extensions of this CertAccessRules.

        A list of extensions formatted as \"oid:value\". Expects the extension value to be some type of ASN1 encoded string. All values must match. Supports globbing on \"value\".  # noqa: E501

        :param bound_extensions: The bound_extensions of this CertAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_extensions = bound_extensions

    @property
    def bound_organizational_units(self):
        """Gets the bound_organizational_units of this CertAccessRules.  # noqa: E501

        A list of Organizational Units names. At least one must exist in the OU field.  # noqa: E501

        :return: The bound_organizational_units of this CertAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_organizational_units

    @bound_organizational_units.setter
    def bound_organizational_units(self, bound_organizational_units):
        """Sets the bound_organizational_units of this CertAccessRules.

        A list of Organizational Units names. At least one must exist in the OU field.  # noqa: E501

        :param bound_organizational_units: The bound_organizational_units of this CertAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_organizational_units = bound_organizational_units

    @property
    def bound_uri_sans(self):
        """Gets the bound_uri_sans of this CertAccessRules.  # noqa: E501

        A list of URIs. At least one must exist in the SANs. Supports globbing.  # noqa: E501

        :return: The bound_uri_sans of this CertAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._bound_uri_sans

    @bound_uri_sans.setter
    def bound_uri_sans(self, bound_uri_sans):
        """Sets the bound_uri_sans of this CertAccessRules.

        A list of URIs. At least one must exist in the SANs. Supports globbing.  # noqa: E501

        :param bound_uri_sans: The bound_uri_sans of this CertAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._bound_uri_sans = bound_uri_sans

    @property
    def certificate(self):
        """Gets the certificate of this CertAccessRules.  # noqa: E501

        Base64 encdoed PEM certificate  # noqa: E501

        :return: The certificate of this CertAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """Sets the certificate of this CertAccessRules.

        Base64 encdoed PEM certificate  # noqa: E501

        :param certificate: The certificate of this CertAccessRules.  # noqa: E501
        :type: str
        """

        self._certificate = certificate

    @property
    def revoked_cert_ids(self):
        """Gets the revoked_cert_ids of this CertAccessRules.  # noqa: E501

        A list of revoked cert ids  # noqa: E501

        :return: The revoked_cert_ids of this CertAccessRules.  # noqa: E501
        :rtype: list[str]
        """
        return self._revoked_cert_ids

    @revoked_cert_ids.setter
    def revoked_cert_ids(self, revoked_cert_ids):
        """Sets the revoked_cert_ids of this CertAccessRules.

        A list of revoked cert ids  # noqa: E501

        :param revoked_cert_ids: The revoked_cert_ids of this CertAccessRules.  # noqa: E501
        :type: list[str]
        """

        self._revoked_cert_ids = revoked_cert_ids

    @property
    def unique_identifier(self):
        """Gets the unique_identifier of this CertAccessRules.  # noqa: E501

        A unique identifier to distinguish different users  # noqa: E501

        :return: The unique_identifier of this CertAccessRules.  # noqa: E501
        :rtype: str
        """
        return self._unique_identifier

    @unique_identifier.setter
    def unique_identifier(self, unique_identifier):
        """Sets the unique_identifier of this CertAccessRules.

        A unique identifier to distinguish different users  # noqa: E501

        :param unique_identifier: The unique_identifier of this CertAccessRules.  # noqa: E501
        :type: str
        """

        self._unique_identifier = unique_identifier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CertAccessRules):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CertAccessRules):
            return True

        return self.to_dict() != other.to_dict()
